@@ -3,8 +3,9 @@ package GitMeta;
 ###########################################
 use strict;
 use warnings;
+use Sysadm::Install qw(:all);
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 ###########################################
 sub new { 
@@ -33,6 +34,18 @@ sub param_check {
   }
 }
 
+###########################################
+sub health_check {
+###########################################
+
+    # Check if we have git in $PATH
+    my( $stdout, $stderr, $rc ) = tap "git", "--version";
+
+    if( $rc ) {
+        die "git not found in path";
+    }
+}
+
 1;
 
 __END__
